==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/redhat/redhat.pm <==
/* redhat.cc 07/12/1999 00.25.58 */
PUBLIC MODULE_redhat::MODULE_redhat (void);
PUBLIC int MODULE_redhat::dohtml (const char *key);
PUBLIC int MODULE_redhat::execmain (int argc, char *argv[]);
/* _dict.cc 01/02/1998 20.19.44 */
/* filter.cc 13/10/1999 03.18.08 */
PRIVATE void CONFDB_REDHAT::reset_modified (void);
PUBLIC CONFDB_REDHAT::CONFDB_REDHAT (CONFDB *_orig);
PUBLIC CONFDB_REDHAT::~CONFDB_REDHAT (void);
PUBLIC void CONFDB_REDHAT::setcursys (const char *_subsys);
PUBLIC int CONFDB_REDHAT::save (PRIVILEGE *priv);
PRIVATE const char *CONFDB_REDHAT::getvalfromrh (RHLK *rh);
PRIVATE void CONFDB_REDHAT::updaterh (RHLK *rh, const char *val);
PUBLIC const char *CONFDB_REDHAT::getval (const char *prefix,
	 const char *key,
	 const char *defval);
PUBLIC int CONFDB_REDHAT::getall (const char *prefix,
	 const char *key,
	 SSTRINGS&lst,
	 bool copy);
PUBLIC void CONFDB_REDHAT::removeall (const char *prefix,
	 const char *key);
PUBLIC void CONFDB_REDHAT::add (const char *prefix,
	 const char *key,
	 const char *val);
PUBLIC int CONFDB_REDHAT::archive (SSTREAM&ss, const char *_sys);
PUBLIC int CONFDB_REDHAT::extract (SSTREAM&ss, const char *_sys);
/* devinfo.cc 23/09/1999 15.21.28 */
PUBLIC CONFIG_FILE_DEVLIST::CONFIG_FILE_DEVLIST (void);
PUBLIC int CONFIG_FILE_DEVLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_DEVLIST::extract (SSTREAM&ss);
/* routes.cc 02/05/1998 22.26.56 */
/* pam.cc 12/01/1999 10.32.06 */
/* reduser.cc 25/11/1999 01.09.46 */
/* sysv.cc 07/12/1999 00.28.30 */
PUBLIC SERVICE_SYSV_REDHAT::SERVICE_SYSV_REDHAT (const char *_name,
	 const char *_desc,
	 int _state);
PUBLIC int SERVICE_SYSV_REDHAT::control (SERVICE_OPER oper);
PUBLIC const char *SERVICE_SYSV_REDHAT::getrunstatus (void);
PUBLIC const char *SERVICE_SYSV_REDHAT::getconfstatus (void);
PUBLIC void SERVICE_SYSV_REDHAT::showstatus (void);
PUBLIC int SERVICE_SYSV_REDHAT::edit (void);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/redhat/redhat.pm <==
/* _dict.cc 01/02/1998 20.19.44 */
/* devinfo.cc 01/12/2000 16.27.36 */
PUBLIC CONFIG_FILE_DEVLIST::CONFIG_FILE_DEVLIST (void);
PUBLIC int CONFIG_FILE_DEVLIST::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_DEVLIST::extract (SSTREAM&ss);
/* filter.cc 16/12/2000 11.45.24 */
PRIVATE void CONFDB_REDHAT::reset_modified (void);
PUBLIC CONFDB_REDHAT::CONFDB_REDHAT (CONFDB *_orig);
PUBLIC CONFDB_REDHAT::~CONFDB_REDHAT (void);
PUBLIC void CONFDB_REDHAT::setcursys (const char *_subsys);
PUBLIC int CONFDB_REDHAT::save (PRIVILEGE *priv);
PRIVATE const char *CONFDB_REDHAT::getvalfromrh (RHLK *rh);
PRIVATE void CONFDB_REDHAT::updaterh (RHLK *rh,
	 const char *key,
	 const char *val);
PUBLIC const char *CONFDB_REDHAT::getval (const char *prefix,
	 const char *key,
	 const char *defval);
PUBLIC int CONFDB_REDHAT::getall (const char *prefix,
	 const char *key,
	 SSTRINGS&lst,
	 bool copy);
PUBLIC void CONFDB_REDHAT::removeall (const char *prefix,
	 const char *key);
PUBLIC void CONFDB_REDHAT::add (const char *prefix,
	 const char *key,
	 const char *val);
PUBLIC int CONFDB_REDHAT::archive (SSTREAM&ss, const char *_sys);
PUBLIC int CONFDB_REDHAT::extract (SSTREAM&ss, const char *_sys);
/* pam.cc 21/08/2000 22.36.34 */
/* redhat.cc 16/12/2000 11.42.34 */
PUBLIC MODULE_redhat::MODULE_redhat (void);
PUBLIC int MODULE_redhat::dohtml (const char *key);
PUBLIC int MODULE_redhat::execmain (int argc, char *argv[], bool);
PUBLIC int MODULE_redhat::message (const char *msg,
	 int argc,
	 const char *argv[]);
/* reduser.cc 15/03/2000 11.29.28 */
/* routes.cc 18/09/2000 17.52.44 */
/* sysv.cc 13/10/2000 13.09.14 */
PUBLIC SERVICE_SYSV_REDHAT::SERVICE_SYSV_REDHAT (const char *_name,
	 const char *_desc,
	 int _state,
	 bool states[7]);
PUBLIC int SERVICE_SYSV_REDHAT::control (SERVICE_OPER oper);
PUBLIC const char *SERVICE_SYSV_REDHAT::getrunstatus (void);
PUBLIC const char *SERVICE_SYSV_REDHAT::getconfstatus (void);
PUBLIC void SERVICE_SYSV_REDHAT::showstatus (void);
PUBLIC int SERVICE_SYSV_REDHAT::install_levels (void);
PRIVATE void SERVICE_SYSV_REDHAT::readinfo (SSTRINGS&desc,
	 char suggest_levels[7]);
PUBLIC int SERVICE_SYSV_REDHAT::edit (void);
PUBLIC CONFIG_FILE_SYSV::CONFIG_FILE_SYSV (void);
PUBLIC int CONFIG_FILE_SYSV::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_SYSV::extract (SSTREAM&ss);
